@@ -15,6 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from io import BytesIO
 import os
 from unittest import mock
 
@@ -30,11 +31,11 @@ from freezer.storage import swift
 
 CONF = cfg.CONF
 os.environ['OS_REGION_NAME'] = 'testregion'
-os.environ['OS_TENANT_ID'] = '0123456789'
+os.environ['OS_PROJECT_ID'] = '0123456789'
 os.environ['OS_PASSWORD'] = 'testpassword'
-os.environ['OS_AUTH_URL'] = 'http://testauthurl/v2.0'
+os.environ['OS_AUTH_URL'] = 'http://testauthurl/v3'
 os.environ['OS_USERNAME'] = 'testusername'
-os.environ['OS_TENANT_NAME'] = 'testtenantename'
+os.environ['OS_PROJECT_NAME'] = 'testtenantename'
 
 
 class FakeSubProcess(object):
@@ -211,7 +212,7 @@ class FakeGlanceClient(object):
 
         @staticmethod
         def data(image):
-            return glance_utils.IterableWithLength(iter("abc"), 3)
+            return glance_utils.IterableWithLength(BytesIO(b"abc"), 3)
 
         @staticmethod
         def delete(image):
@@ -321,7 +322,6 @@ class BackupOpt1(object):
         self.dereference_symlink = None
         self.mysql_conf = '/tmp/freezer-test-conf-file'
         self.backup_media = 'fs'
-        self.lvm_auto_snap = '/dev/null'
         self.lvm_volgroup = 'testgroup'
         self.lvm_srcvol = 'testvol'
         self.lvm_dirmount = '/tmp/testdir'
