@@ -14,11 +14,14 @@
 # limitations under the License.
 
 import datetime
+import fixtures
+from io import BytesIO
 import os
 import time
+from unittest import mock
+from unittest.mock import patch
 
-from mock import patch
-
+from freezer.exceptions import utils as exception_utils
 from freezer.openstack import osclients
 from freezer.tests import commons
 from freezer.utils import utils
@@ -74,24 +77,24 @@ class TestUtils(commons.FreezerBaseTestCase):
                 self.__dict__.update(opts)
 
         env_dict = dict(OS_USERNAME='testusername',
-                        OS_TENANT_NAME='testtenantename',
+                        OS_PROJECT_NAME='testtenantename',
                         OS_AUTH_URL='testauthurl',
                         OS_PASSWORD='testpassword',
                         OS_REGION_NAME='testregion',
-                        OS_TENANT_ID='0123456789',
+                        OS_PROJECT_ID='0123456789',
                         OS_AUTH_VERSION='2.0')
         options = osclients.OpenstackOpts.create_from_dict(
             env_dict).get_opts_dicts()
         options = FreezerOpts(options)
         assert options.username == env_dict['OS_USERNAME']
-        assert options.tenant_name == env_dict['OS_TENANT_NAME']
+        assert options.project_name == env_dict['OS_PROJECT_NAME']
         assert options.auth_url == env_dict['OS_AUTH_URL']
         assert options.password == env_dict['OS_PASSWORD']
         assert options.region_name == env_dict['OS_REGION_NAME']
-        assert options.tenant_id == env_dict['OS_TENANT_ID']
+        assert options.project_id == env_dict['OS_PROJECT_ID']
 
         env_dict = dict(OS_USERNAME='testusername',
-                        OS_TENANT_NAME='testtenantename',
+                        OS_PROJECT_NAME='testtenantename',
                         OS_AUTH_URL='testauthurl',
                         OS_PASSWORD='testpassword',
                         OS_AUTH_VERSION='2.0')
@@ -99,7 +102,7 @@ class TestUtils(commons.FreezerBaseTestCase):
             env_dict).get_opts_dicts()
         options = FreezerOpts(options)
         assert options.username == env_dict['OS_USERNAME']
-        assert options.tenant_name == env_dict['OS_TENANT_NAME']
+        assert options.project_name == env_dict['OS_PROJECT_NAME']
         assert options.auth_url == env_dict['OS_AUTH_URL']
         assert options.password == env_dict['OS_PASSWORD']
 
@@ -109,8 +112,9 @@ class TestUtils(commons.FreezerBaseTestCase):
             "2014-12-03T23:23:23")
 
     def prepare_env(self):
-        os.environ["HTTP_PROXY"] = 'http://proxy.original.domain:8080'
-        os.environ.pop("HTTPS_PROXY", None)
+        self.useFixture(fixtures.EnvironmentVariable(
+            "HTTP_PROXY", 'http://proxy.original.domain:8080'))
+        self.useFixture(fixtures.EnvironmentVariable("HTTPS_PROXY"))
 
     def test_alter_proxy(self):
         """
@@ -158,7 +162,7 @@ class TestUtils(commons.FreezerBaseTestCase):
     def test_walk_path_file(self, mock_isfile):
         mock_isfile.return_value = True
         count = utils.walk_path('root', '', False, self.callback)
-        assert count is 1
+        assert count == 1
 
     def callback(self, filepath='', files=[]):
         files.append(filepath)
@@ -202,3 +206,40 @@ class TestDateTime(object):
         d2 = datetime.datetime(2015, 3, 7, 18, 18, 38, 508411)
         ts2 = utils.DateTime(d2)
         assert '0:30:53.791612' == '{}'.format(ts2 - self.datetime)
+
+    def test_wait_for_positive(self):
+        condition = mock.MagicMock(side_effect=[False, False, True, True])
+        utils.wait_for(condition, 0.1, 1)
+        self.assertEqual(3, condition.called)
+
+    def test_wait_for_negative(self):
+        condition = mock.MagicMock(side_effect=[False, False, False])
+        self.assertRaises(exception_utils.TimeoutException,
+                          utils.wait_for(condition, 0.1, 0.2))
+
+
+class TestReSizeStream(commons.FreezerBaseTestCase):
+    def test_next(self):
+        stream_data = b"12345"
+        stream = BytesIO(stream_data)
+        chunk_size = len(stream_data) - 1
+        resize_stream = utils.ReSizeStream(
+            stream=stream,
+            length=len(stream_data),
+            chunk_size=chunk_size,
+        )
+        next_result = next(resize_stream)
+        self.assertEqual(chunk_size, len(next_result))
+        self.assertEqual(stream_data[:chunk_size], next_result)
+        self.assertIsInstance(next_result, bytes)
+
+    def test_read(self):
+        stream_data = b"abcdef"
+        chunk_size = 2
+        resize_stream = utils.ReSizeStream(
+            stream=BytesIO(stream_data),
+            length=len(stream_data),
+            chunk_size=chunk_size,
+        )
+        read_result = resize_stream.read(chunk_size)
+        self.assertEqual(stream_data[:chunk_size], read_result)
